import { AfterViewInit, ElementRef, EventEmitter } from '@angular/core';
import * as _ from 'lodash';
/**
 * A component which renders indicators when there is hidden content which can be scrolled to bring into view.  It wraps
 * your contents and adds arrows which display when the user has scrolled more than 10 pixels from the top or bottom of
 * the contents.
 *
 * IMPORTANT: If you need a buffer between the element upon which you attach the directive and the content (eg: for the
 * table headers in a <table>):
 *
 *      1) Attach the local var `#scrollableComponent` to the <scrollable-container> tag as shown below.
 *
 *      2) Attach the local var `#scrollableContent` to the scrollable content's container.
 *
 *      3) Add a `scroll` event handler which calls `scrollableComponent.onScroll()` to the same element with
 *          `#scrollableContent`.
 *
 *      4) Add the `#scrollableTop` local var to the element directly above your scrollable content in the DOM tree,
 *          which will act as a buffer between the top of the `scrollable-container` tag and the scrollable content.
 *
 * See demo implementation for styles.
 *
 * ### Simple Example
 *
 * Using table, buffer needed for table headers:
 * ```
 *  <scrollable-container #scrollableComponent>
 *      <table>
 *          <thead #scrollableTop>
 *              <tr>...</tr>
 *              <tr>...</tr>
 *              <tr>...</tr>
 *          </thead>
 *          <tbody #scrollableContent (scroll)="scrollableComponent.onScroll()">
 *              <td>...</td>
 *              <td>...</td>
 *          </tbody>
 *      </table>
 *  </scrollable-container>
 * ```
 *
 * Using divs, no buffer needed for table headers:
 * ```
 *  <scrollable-container>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *      <div>
 *          my content
 *      </div>
 *  </scrollable-container>
 * ```
 */
export declare class HintScroll implements AfterViewInit {
    private el;
    private targetContainer;
    private top;
    checkedVisibility: EventEmitter<{}>;
    newContentLoaded: boolean;
    private scrollableEl;
    private fromTop;
    onScroll: (() => void) & _.Cancelable;
    constructor(el: ElementRef);
    ngAfterViewInit(): void;
    private showTop();
    private showBottom();
    private verifyVisibility();
}
