import { AfterViewInit, ElementRef, Renderer } from '@angular/core';
import { TooltipService } from '../../directives/tooltip/tooltip-service';
/**
 * This is a tooltip component which is intended to be placed in the template of the root component of your application.
 * It communicates with the tooltip directive included in this library via the tooltip service, also included in this
 * library.  When it receives new state from a tooltip directive via the service, it updates its position and content.
 *
 * ** IMPORTANT ** It is important that this component be placed in the template of your app's root component!  The
 * positioning logic relies on this.
 *
 * Simple usage example:
 *
 * 1) Include TooltipService in the `providers` section of ngModule, in app.module.ts for example:
 * ```
 *  @NgModule({
 *     bootstrap:    [ AppComponent ],
 *     declarations: [
 *         AppsMain,
 *         ContextBar,
 *         Row
 *     ],
 *     imports:      [
 *         BrowserModule,
 *         HttpModule,
 *         Ng2UEUtilsModule,
 *         RouterModule.forRoot(appLocalRoutes)
 *     ],
 *     providers: [
 *         AppClient,
 *         AppRepository,
 *         NotificationService,
 *         TooltipService, // ** HERE **
 *         ProgressService,
 *         Location,
 *         WindowRef,
 *         { provide: APP_CONFIG, useValue: appConfig }
 *     ]
 * })
 *  export class AppModule {}
 * ```
 *
 * 2) Add the tooltip component to your root component's template, eg: app.component.ts:
 *
 * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <router-outlet></router-outlet>
 *        <ue-tooltip></ue-tooltip>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 * **Important** The tooltip component should be included in your root component template and not any lower.  It relies
 * on this placement to properly position itself around the page.
 *
 *
 * 3) Finally, use the directive somewhere in your app:
 *
 *  * ```
 * import { Component } from '@angular/core';
 *
 * @Component({
 *    selector: 'app',
 *    template: `
 *        <div ueTooltip="This is a div"></div>
 *    `
 * })
 * export class AppComponent {}
 *
 * ```
 *
 *   ** SEE THE DEMO for examples of more advanced usage **
 */
export declare type TooltipPlacement = 'top' | 'bottom' | 'left' | 'right';
export interface IPositions {
    top: number;
    left: number;
}
export interface ITooltipOptions {
    content?: string;
    enabled?: boolean;
    hovering?: boolean;
    maxWidth?: number;
    placement?: TooltipPlacement;
    target?: HTMLElement;
}
export declare class Tooltip implements AfterViewInit {
    private service;
    private renderer;
    options: ITooltipOptions;
    showTooltip: boolean;
    disabled: boolean;
    tooltipContainer: ElementRef;
    constructor(service: TooltipService, renderer: Renderer);
    ngAfterViewInit(): void;
    private setOptions(options);
    private positionTooltip();
    private setNewPosition(tooltip, positions);
    private calculatePositions(target, tooltip, placement);
    private edgePosition(target, tooltip, placement, styleProp);
    private centeredPosition(target, tooltip, styleProp);
}
