import { Observable } from 'rxjs/Rx';
import { ISimplifiedError } from './client';
/**
 * This injectable service can optionally be provided to the ObservableClient or ObservableClientBase classes included
 * in this library in order to provide you with a stream of http call status represented as IClientEvent emissions.
 *
 * The spy (ClientObserver) is designed to allow you to feed client events into the progress service to update the
 * state of your progress bar component, both of which are also included in this library. You can also use it to feed error notifications
 * using the notification service and notifications component.
 *
 * If used together with the Client included in this library, the emissions are IClientEvents that have the following information:
 * stackCount: the number of calls in flight, so you know if there are any pending calls
 * event: a ClientEvent, which can have the values 'error' | 'start' | 'complete' | 'next'
 * method: a ClientMethod, which can have the values 'get' | 'put' | 'post' | 'delete'
 * error: if the client call resulted in an error, a readable string representing the error cause
 * errorInfo: if the client call resulted in an error, ISimplifiedError including a message, code, path and the original error response.
 *          Use this object to parse errors if you need something specific for your app.
 * path: a string of the relative path for the http call that was made
 *
 * ### Simple Example
 *
 * Add service to your app module so it can be injected into your components
 *
 * ```
 * import { Ng2UEUtilsModule, ClientObserver } from 'ng2-ue-utils';
 * import { AppComponent } from './path/to/appComponent';
 * import { MyComponent } from './path/to/myComponent';
 *
 * @NgModule({
 *   bootstrap:     [ AppComponent ],
 *   declarations:  [ AppComponent, MyComponent ],
 *   imports:       [ Ng2UEUtilsModule ],
 *   providers:     [ ClientObserver ]
 * })
 * ```
 *
 * And in myComponent.ts
 * ```
 * import { ClientObserver } from 'ng2-ue-utils';
 *
 * @Component({
 *     selector: 'my-component',
 *     template: `<div> my content </div>`
 * })
 * class MyComponent {
 *
 *     constructor(private progressService: ProgressService, private spy: ClientObserver){}
 *
 *     private subscribeToServerCallsEvents () {
 *       this.spy.clientEvents
 *          .filter(status => status.event !== 'next')
 *          .subscribe((event: IClientEvent) => {
 *               this.progressService.notify(event);
 *           });
 *     }
 * }
 * ```
 */
export declare type ClientEvent = 'error' | 'start' | 'complete' | 'next';
export declare type ClientMethod = 'get' | 'put' | 'post' | 'delete';
export interface IClientEvent {
    stackCount: number;
    event: ClientEvent;
    method: ClientMethod;
    error?: any;
    errorInfo?: ISimplifiedError;
    path?: string;
}
export declare class ClientObserver {
    private _emitter;
    private _stackCount;
    clientEvents: Observable<IClientEvent>;
    private countUp;
    private countDown;
    emitChange: (event: ClientEvent, method: ClientMethod, path?: string, error?: any) => void;
    observeOn: <T>(method: ClientMethod, obs: Observable<T>, path?: string) => Observable<T>;
}
