import { OpaqueToken } from '@angular/core';
import { Location } from '@angular/common';
import 'rxjs/Rx';
import { WindowRef } from '../window-ref';
/**
 * This interface is the one that your app should be implementing to configure main paths to your API and basepath for your app URL
 * appBasePath will be used to build the main URL for your root component
 * apiBasePath will be used to build API calls
 * gtmAppName will be used to identify your google tag manager configuration
 *
 * ### Example: api products.
 * You want your api calls going to /organizations/organizationname/apiproducts
 * You want your SPA to have /products as your root URL
 * You want gtm to identify your app as productsSPA
 * You will need to create your appConfig in your app.component file (see example of that file below)
 *
 * const appConfig: IAppConfig = {
 *   apiBasePath: 'apiproducts',
 *   appBasePath: 'products',
 *   gtmAppName: 'productsSPA'
 * };
 *
 */
export interface IAppConfig {
    appBasePath: string;
    apiBasePath: string;
    gtmAppName: string;
}
export declare const APP_CONFIG: OpaqueToken;
export interface IContext {
    orgName: string;
}
export declare class Context implements IContext {
    private _orgName;
    constructor(_orgName: any);
    readonly orgName: string;
}
/**
 * This service is used to get the organization and user context in which an SPA is being used.
 * Ideally, it should be included as part of your providers in your app.component file so all the application has access to it.
 * Its dependencies must be provided in app.component as well.
 * So, your app.component.ts should look something like this
 *
 * ```
 * import { Location } from '@angular/common';
 * import { Component } from '@angular/core';
 * import { HTTP_PROVIDERS } from '@angular/http';
 * import { APP_CONFIG, ContextService, Client, IAppConfig, WindowRef } from 'ng2-ue-utils';
 *
 * import { MyMainComponent } from './route/to/myMainComponent';
 *
 * const appConfig: IAppConfig = {
 *   apiBasePath: 'myapibasepath',
 *   appBasePath: 'myappbasepath',
 *   gtmAppName: 'nameforgoogletagmanager'
 * };
 *
 * @Component({
 *   directives: [
 *       MyMainComponent
 *   ],
 *   providers: [
 *       HTTP_PROVIDERS,
 *       Location,
 *       Client,
 *       ContextService,
 *       WindowRef,
 *       { provide: APP_CONFIG, useValue: appConfig }
 *   ],
 *   selector: 'app',
 *   template: '<myMainComponent-or-routerOutlet></myMainComponent-or-routerOutlet>'
 * })
 * export class AppComponent {}
 * ```
 *
 * The most common usage for it is to get the organization name inside a component.
 * To do that inject it in the component constructor and do
 *
 * ```
 * const org: string = this.context.orgName;
 * ```
 *
 */
export declare class ContextService {
    private location;
    private window;
    private appConfig;
    private _orgName;
    private helper;
    constructor(location: Location, window: WindowRef, appConfig: IAppConfig);
    getContext(): IContext;
    readonly orgName: string;
    readonly userEmail: string;
}
